| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
CabalGild.Type.Extension
Documentation
This type exists to provide a different Ord instance for
Extension. The instance provided by Cabal-syntax sorts things
in a surprising order. This one sorts things alphabetically with "enable"
extensions before "disable" ones.
Instances
| Parsec Extension Source # | |
Defined in CabalGild.Type.Extension Methods parsec :: CabalParsing m => m Extension # | |
| Pretty Extension Source # | |
Defined in CabalGild.Type.Extension | |
| Show Extension Source # | |
| Eq Extension Source # | |
| Ord Extension Source # | |
isDisable :: Extension -> Bool Source #
Returns True if the given extension is either a
DisableExtension or it's an UnknownExtension that
starts with No followed by an uppercase letter.